<?php

/* utf8-marker = äöü
==========================================
CMSimple Plugin LoginLocker
Version loginlocker 2.1
Release: 2013-04-04
Idea: Gert Ebersbach http://www.ge-webdesign.de
Programming: Martin Damken http://www.zeichenkombinat.de
==========================================
License: GPL3 - no warranties
==========================================
*/

class CMSimpleLoginLock
{
    var $max_inactivity;
    var $warn_before = 20;
    var $pluginName  = 'loginlocker';
    var $lockFile    = '';
    var $version     = '2.1';

    function CMSimpleLoginLock($dir = null)
    {
        global $plugin_cf;

        if (!$dir)
        {
            $dir = getcwd();
        }

        $this->lockFile = $dir . '/content/.loginlock';

        if (!file_exists($this->lockFile))
        {
            touch($this->lockFile, time() - (int) ini_get('session.gc_maxlifetime'));
        }

        $this->max_inactivity = (int) $plugin_cf[$this->pluginName]['max_inactivity'] >= 30 ? (int) $plugin_cf[$this->pluginName]['max_inactivity'] : 30;

        if ($this->max_inactivity > (int) ini_get('session.gc_maxlifetime'))
        {
            $this->max_inactivity = (int) ini_get('session.gc_maxlifetime');
        }

        if (isset($plugin_cf[$this->pluginName]['warn_before']) && (int) $plugin_cf[$this->pluginName]['warn_before'] > 0 && $plugin_cf[$this->pluginName]['warn_before'] < $plugin_cf[$this->pluginName]['max_inactivity'])
        {
            $this->warn_before = $plugin_cf[$this->pluginName]['warn_before'];
        }
    }

    function isLocked()
    {
        return time() < filemtime($this->lockFile) + $this->max_inactivity;
    }

    function hasExpired()
    {
        return time() > filemtime($this->lockFile) + $this->max_inactivity;
    }

    function lock()
    {
        touch($this->lockFile);
    }

    function unlock()
    {
        touch($this->lockFile, time() - $this->max_inactivity + 4);
    }

    function logOut()
    {
        global $sn, $u;
        $this->unlock();
        if (!isset($_GET['logout']))
        {
            header('Location: ' . $sn . '?' . '&logout&logged-out');
            exit;
        }
    }

    function error($message, $args = null)
    {
        global $o, $e;
        $o .= '<p class="cmsimplecore_warning" style="text-align: center; padding: 16px 24px;">' . $this->translate($message, $args) . '</p>' . "\n";
    }

    function translate($message, $args = null)
    {
        global $plugin_tx;

        $message = isset($plugin_tx[$this->pluginName][$message]) ? $plugin_tx[$this->pluginName][$message] : '{' . $message . '}';

        if (is_array($args) && count($args) > 0)
        {
            array_unshift($args, $message);
            $message = call_user_func_array('sprintf', $args);
        }

        if (is_string($args) && strlen($args) > 0)
        {
            $message = sprintf($message, $args);
        }
        return $message;
    }
}

?>
